==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkMapper.java <==
// java wrapper for vtkMapper object
//

package vtk;
import vtk.*;

public class vtkMapper extends vtkAbstractMapper3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ShallowCopy_2(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_2(id0); }

  private native int GetMTime_3();
  public int GetMTime()
    { return GetMTime_3(); }

  private native void Render_4(vtkRenderer id0,vtkActor id1);
  public void Render(vtkRenderer id0,vtkActor id1)
    { Render_4(id0,id1); }

  private native void ReleaseGraphicsResources_5(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_5(id0); }

  private native void SetLookupTable_6(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_6(id0); }

  private native long GetLookupTable_7();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_7();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultLookupTable_8();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_8(); }

  private native void SetScalarVisibility_9(int id0);
  public void SetScalarVisibility(int id0)
    { SetScalarVisibility_9(id0); }

  private native int GetScalarVisibility_10();
  public int GetScalarVisibility()
    { return GetScalarVisibility_10(); }

  private native void ScalarVisibilityOn_11();
  public void ScalarVisibilityOn()
    { ScalarVisibilityOn_11(); }

  private native void ScalarVisibilityOff_12();
  public void ScalarVisibilityOff()
    { ScalarVisibilityOff_12(); }

  private native void SetStatic_13(int id0);
  public void SetStatic(int id0)
    { SetStatic_13(id0); }

  private native int GetStatic_14();
  public int GetStatic()
    { return GetStatic_14(); }

  private native void StaticOn_15();
  public void StaticOn()
    { StaticOn_15(); }

  private native void StaticOff_16();
  public void StaticOff()
    { StaticOff_16(); }

  private native void SetColorMode_17(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_17(id0); }

  private native int GetColorMode_18();
  public int GetColorMode()
    { return GetColorMode_18(); }

  private native void SetColorModeToDefault_19();
  public void SetColorModeToDefault()
    { SetColorModeToDefault_19(); }

  private native void SetColorModeToMapScalars_20();
  public void SetColorModeToMapScalars()
    { SetColorModeToMapScalars_20(); }

  private native void SetColorModeToDirectScalars_21();
  public void SetColorModeToDirectScalars()
    { SetColorModeToDirectScalars_21(); }

  private native String GetColorModeAsString_22();
  public String GetColorModeAsString()
    { return GetColorModeAsString_22(); }

  private native void SetInterpolateScalarsBeforeMapping_23(int id0);
  public void SetInterpolateScalarsBeforeMapping(int id0)
    { SetInterpolateScalarsBeforeMapping_23(id0); }

  private native int GetInterpolateScalarsBeforeMapping_24();
  public int GetInterpolateScalarsBeforeMapping()
    { return GetInterpolateScalarsBeforeMapping_24(); }

  private native void InterpolateScalarsBeforeMappingOn_25();
  public void InterpolateScalarsBeforeMappingOn()
    { InterpolateScalarsBeforeMappingOn_25(); }

  private native void InterpolateScalarsBeforeMappingOff_26();
  public void InterpolateScalarsBeforeMappingOff()
    { InterpolateScalarsBeforeMappingOff_26(); }

  private native void SetUseLookupTableScalarRange_27(int id0);
  public void SetUseLookupTableScalarRange(int id0)
    { SetUseLookupTableScalarRange_27(id0); }

  private native int GetUseLookupTableScalarRange_28();
  public int GetUseLookupTableScalarRange()
    { return GetUseLookupTableScalarRange_28(); }

  private native void UseLookupTableScalarRangeOn_29();
  public void UseLookupTableScalarRangeOn()
    { UseLookupTableScalarRangeOn_29(); }

  private native void UseLookupTableScalarRangeOff_30();
  public void UseLookupTableScalarRangeOff()
    { UseLookupTableScalarRangeOff_30(); }

  private native void SetScalarRange_31(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_31(id0,id1); }

  private native void SetScalarRange_32(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_32(id0); }

  private native double[] GetScalarRange_33();
  public double[] GetScalarRange()
    { return GetScalarRange_33(); }

  private native void SetImmediateModeRendering_34(int id0);
  public void SetImmediateModeRendering(int id0)
    { SetImmediateModeRendering_34(id0); }

  private native int GetImmediateModeRendering_35();
  public int GetImmediateModeRendering()
    { return GetImmediateModeRendering_35(); }

  private native void ImmediateModeRenderingOn_36();
  public void ImmediateModeRenderingOn()
    { ImmediateModeRenderingOn_36(); }

  private native void ImmediateModeRenderingOff_37();
  public void ImmediateModeRenderingOff()
    { ImmediateModeRenderingOff_37(); }

  private native void SetGlobalImmediateModeRendering_38(int id0);
  public void SetGlobalImmediateModeRendering(int id0)
    { SetGlobalImmediateModeRendering_38(id0); }

  private native void GlobalImmediateModeRenderingOn_39();
  public void GlobalImmediateModeRenderingOn()
    { GlobalImmediateModeRenderingOn_39(); }

  private native void GlobalImmediateModeRenderingOff_40();
  public void GlobalImmediateModeRenderingOff()
    { GlobalImmediateModeRenderingOff_40(); }

  private native int GetGlobalImmediateModeRendering_41();
  public int GetGlobalImmediateModeRendering()
    { return GetGlobalImmediateModeRendering_41(); }

  private native int GetForceCompileOnly_42();
  public int GetForceCompileOnly()
    { return GetForceCompileOnly_42(); }

  private native void SetForceCompileOnly_43(int id0);
  public void SetForceCompileOnly(int id0)
    { SetForceCompileOnly_43(id0); }

  private native void SetScalarMode_44(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_44(id0); }

  private native int GetScalarMode_45();
  public int GetScalarMode()
    { return GetScalarMode_45(); }

  private native void SetScalarModeToDefault_46();
  public void SetScalarModeToDefault()
    { SetScalarModeToDefault_46(); }

  private native void SetScalarModeToUsePointData_47();
  public void SetScalarModeToUsePointData()
    { SetScalarModeToUsePointData_47(); }

  private native void SetScalarModeToUseCellData_48();
  public void SetScalarModeToUseCellData()
    { SetScalarModeToUseCellData_48(); }

  private native void SetScalarModeToUsePointFieldData_49();
  public void SetScalarModeToUsePointFieldData()
    { SetScalarModeToUsePointFieldData_49(); }

  private native void SetScalarModeToUseCellFieldData_50();
  public void SetScalarModeToUseCellFieldData()
    { SetScalarModeToUseCellFieldData_50(); }

  private native void SetScalarModeToUseFieldData_51();
  public void SetScalarModeToUseFieldData()
    { SetScalarModeToUseFieldData_51(); }

  private native void SelectColorArray_52(int id0);
  public void SelectColorArray(int id0)
    { SelectColorArray_52(id0); }

  private native void SelectColorArray_53(String id0);
  public void SelectColorArray(String id0)
    { SelectColorArray_53(id0); }

  private native void SetFieldDataTupleId_54(int id0);
  public void SetFieldDataTupleId(int id0)
    { SetFieldDataTupleId_54(id0); }

  private native int GetFieldDataTupleId_55();
  public int GetFieldDataTupleId()
    { return GetFieldDataTupleId_55(); }

  private native void ColorByArrayComponent_56(int id0,int id1);
  public void ColorByArrayComponent(int id0,int id1)
    { ColorByArrayComponent_56(id0,id1); }

  private native void ColorByArrayComponent_57(String id0,int id1);
  public void ColorByArrayComponent(String id0,int id1)
    { ColorByArrayComponent_57(id0,id1); }

  private native String GetArrayName_58();
  public String GetArrayName()
    { return GetArrayName_58(); }

  private native int GetArrayId_59();
  public int GetArrayId()
    { return GetArrayId_59(); }

  private native int GetArrayAccessMode_60();
  public int GetArrayAccessMode()
    { return GetArrayAccessMode_60(); }

  private native int GetArrayComponent_61();
  public int GetArrayComponent()
    { return GetArrayComponent_61(); }

  private native String GetScalarModeAsString_62();
  public String GetScalarModeAsString()
    { return GetScalarModeAsString_62(); }

  private native void SetResolveCoincidentTopology_63(int id0);
  public void SetResolveCoincidentTopology(int id0)
    { SetResolveCoincidentTopology_63(id0); }

  private native int GetResolveCoincidentTopology_64();
  public int GetResolveCoincidentTopology()
    { return GetResolveCoincidentTopology_64(); }

  private native void SetResolveCoincidentTopologyToDefault_65();
  public void SetResolveCoincidentTopologyToDefault()
    { SetResolveCoincidentTopologyToDefault_65(); }

  private native void SetResolveCoincidentTopologyToOff_66();
  public void SetResolveCoincidentTopologyToOff()
    { SetResolveCoincidentTopologyToOff_66(); }

  private native void SetResolveCoincidentTopologyToPolygonOffset_67();
  public void SetResolveCoincidentTopologyToPolygonOffset()
    { SetResolveCoincidentTopologyToPolygonOffset_67(); }

  private native void SetResolveCoincidentTopologyToShiftZBuffer_68();
  public void SetResolveCoincidentTopologyToShiftZBuffer()
    { SetResolveCoincidentTopologyToShiftZBuffer_68(); }

  private native void SetResolveCoincidentTopologyPolygonOffsetParameters_69(double id0,double id1);
  public void SetResolveCoincidentTopologyPolygonOffsetParameters(double id0,double id1)
    { SetResolveCoincidentTopologyPolygonOffsetParameters_69(id0,id1); }

  private native void SetResolveCoincidentTopologyPolygonOffsetFaces_70(int id0);
  public void SetResolveCoincidentTopologyPolygonOffsetFaces(int id0)
    { SetResolveCoincidentTopologyPolygonOffsetFaces_70(id0); }

  private native int GetResolveCoincidentTopologyPolygonOffsetFaces_71();
  public int GetResolveCoincidentTopologyPolygonOffsetFaces()
    { return GetResolveCoincidentTopologyPolygonOffsetFaces_71(); }

  private native void SetResolveCoincidentTopologyZShift_72(double id0);
  public void SetResolveCoincidentTopologyZShift(double id0)
    { SetResolveCoincidentTopologyZShift_72(id0); }

  private native double GetResolveCoincidentTopologyZShift_73();
  public double GetResolveCoincidentTopologyZShift()
    { return GetResolveCoincidentTopologyZShift_73(); }

  private native double[] GetBounds_74();
  public double[] GetBounds()
    { return GetBounds_74(); }

  private native void GetBounds_75(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_75(id0); }

  private native void SetRenderTime_76(double id0);
  public void SetRenderTime(double id0)
    { SetRenderTime_76(id0); }

  private native double GetRenderTime_77();
  public double GetRenderTime()
    { return GetRenderTime_77(); }

  private native long GetInputAsDataSet_78();
  public vtkDataSet GetInputAsDataSet() {
    long temp = GetInputAsDataSet_78();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long MapScalars_79(double id0);
  public vtkUnsignedCharArray MapScalars(double id0) {
    long temp = MapScalars_79(id0);

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long MapScalars_80(vtkDataSet id0,double id1);
  public vtkUnsignedCharArray MapScalars(vtkDataSet id0,double id1) {
    long temp = MapScalars_80(id0,id1);

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetScalarMaterialMode_81(int id0);
  public void SetScalarMaterialMode(int id0)
    { SetScalarMaterialMode_81(id0); }

  private native int GetScalarMaterialMode_82();
  public int GetScalarMaterialMode()
    { return GetScalarMaterialMode_82(); }

  private native void SetScalarMaterialModeToDefault_83();
  public void SetScalarMaterialModeToDefault()
    { SetScalarMaterialModeToDefault_83(); }

  private native void SetScalarMaterialModeToAmbient_84();
  public void SetScalarMaterialModeToAmbient()
    { SetScalarMaterialModeToAmbient_84(); }

  private native void SetScalarMaterialModeToDiffuse_85();
  public void SetScalarMaterialModeToDiffuse()
    { SetScalarMaterialModeToDiffuse_85(); }

  private native void SetScalarMaterialModeToAmbientAndDiffuse_86();
  public void SetScalarMaterialModeToAmbientAndDiffuse()
    { SetScalarMaterialModeToAmbientAndDiffuse_86(); }

  private native String GetScalarMaterialModeAsString_87();
  public String GetScalarMaterialModeAsString()
    { return GetScalarMaterialModeAsString_87(); }

  private native boolean GetIsOpaque_88();
  public boolean GetIsOpaque()
    { return GetIsOpaque_88(); }

  private native boolean GetSupportsSelection_89();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_89(); }

  private native int CanUseTextureMapForColoring_90(vtkDataObject id0);
  public int CanUseTextureMapForColoring(vtkDataObject id0)
    { return CanUseTextureMapForColoring_90(id0); }

  public vtkMapper() { super(); }

  public vtkMapper(long id) { super(id); }

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkMapper.java <==
// java wrapper for vtkMapper object
//

package vtk;
import vtk.*;

public class vtkMapper extends vtkAbstractMapper3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ShallowCopy_2(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_2(id0); }

  private native int GetMTime_3();
  public int GetMTime()
    { return GetMTime_3(); }

  private native void Render_4(vtkRenderer id0,vtkActor id1);
  public void Render(vtkRenderer id0,vtkActor id1)
    { Render_4(id0,id1); }

  private native void ReleaseGraphicsResources_5(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_5(id0); }

  private native void SetLookupTable_6(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_6(id0); }

  private native long GetLookupTable_7();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_7();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLookupTable_8();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_8(); }

  private native void SetScalarVisibility_9(int id0);
  public void SetScalarVisibility(int id0)
    { SetScalarVisibility_9(id0); }

  private native int GetScalarVisibility_10();
  public int GetScalarVisibility()
    { return GetScalarVisibility_10(); }

  private native void ScalarVisibilityOn_11();
  public void ScalarVisibilityOn()
    { ScalarVisibilityOn_11(); }

  private native void ScalarVisibilityOff_12();
  public void ScalarVisibilityOff()
    { ScalarVisibilityOff_12(); }

  private native void SetStatic_13(int id0);
  public void SetStatic(int id0)
    { SetStatic_13(id0); }

  private native int GetStatic_14();
  public int GetStatic()
    { return GetStatic_14(); }

  private native void StaticOn_15();
  public void StaticOn()
    { StaticOn_15(); }

  private native void StaticOff_16();
  public void StaticOff()
    { StaticOff_16(); }

  private native void SetColorMode_17(int id0);
  public void SetColorMode(int id0)
    { SetColorMode_17(id0); }

  private native int GetColorMode_18();
  public int GetColorMode()
    { return GetColorMode_18(); }

  private native void SetColorModeToDefault_19();
  public void SetColorModeToDefault()
    { SetColorModeToDefault_19(); }

  private native void SetColorModeToMapScalars_20();
  public void SetColorModeToMapScalars()
    { SetColorModeToMapScalars_20(); }

  private native void SetColorModeToDirectScalars_21();
  public void SetColorModeToDirectScalars()
    { SetColorModeToDirectScalars_21(); }

  private native String GetColorModeAsString_22();
  public String GetColorModeAsString()
    { return GetColorModeAsString_22(); }

  private native void SetInterpolateScalarsBeforeMapping_23(int id0);
  public void SetInterpolateScalarsBeforeMapping(int id0)
    { SetInterpolateScalarsBeforeMapping_23(id0); }

  private native int GetInterpolateScalarsBeforeMapping_24();
  public int GetInterpolateScalarsBeforeMapping()
    { return GetInterpolateScalarsBeforeMapping_24(); }

  private native void InterpolateScalarsBeforeMappingOn_25();
  public void InterpolateScalarsBeforeMappingOn()
    { InterpolateScalarsBeforeMappingOn_25(); }

  private native void InterpolateScalarsBeforeMappingOff_26();
  public void InterpolateScalarsBeforeMappingOff()
    { InterpolateScalarsBeforeMappingOff_26(); }

  private native void SetUseLookupTableScalarRange_27(int id0);
  public void SetUseLookupTableScalarRange(int id0)
    { SetUseLookupTableScalarRange_27(id0); }

  private native int GetUseLookupTableScalarRange_28();
  public int GetUseLookupTableScalarRange()
    { return GetUseLookupTableScalarRange_28(); }

  private native void UseLookupTableScalarRangeOn_29();
  public void UseLookupTableScalarRangeOn()
    { UseLookupTableScalarRangeOn_29(); }

  private native void UseLookupTableScalarRangeOff_30();
  public void UseLookupTableScalarRangeOff()
    { UseLookupTableScalarRangeOff_30(); }

  private native void SetScalarRange_31(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_31(id0,id1); }

  private native void SetScalarRange_32(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_32(id0); }

  private native double[] GetScalarRange_33();
  public double[] GetScalarRange()
    { return GetScalarRange_33(); }

  private native void SetImmediateModeRendering_34(int id0);
  public void SetImmediateModeRendering(int id0)
    { SetImmediateModeRendering_34(id0); }

  private native int GetImmediateModeRendering_35();
  public int GetImmediateModeRendering()
    { return GetImmediateModeRendering_35(); }

  private native void ImmediateModeRenderingOn_36();
  public void ImmediateModeRenderingOn()
    { ImmediateModeRenderingOn_36(); }

  private native void ImmediateModeRenderingOff_37();
  public void ImmediateModeRenderingOff()
    { ImmediateModeRenderingOff_37(); }

  private native void SetGlobalImmediateModeRendering_38(int id0);
  public void SetGlobalImmediateModeRendering(int id0)
    { SetGlobalImmediateModeRendering_38(id0); }

  private native void GlobalImmediateModeRenderingOn_39();
  public void GlobalImmediateModeRenderingOn()
    { GlobalImmediateModeRenderingOn_39(); }

  private native void GlobalImmediateModeRenderingOff_40();
  public void GlobalImmediateModeRenderingOff()
    { GlobalImmediateModeRenderingOff_40(); }

  private native int GetGlobalImmediateModeRendering_41();
  public int GetGlobalImmediateModeRendering()
    { return GetGlobalImmediateModeRendering_41(); }

  private native int GetForceCompileOnly_42();
  public int GetForceCompileOnly()
    { return GetForceCompileOnly_42(); }

  private native void SetForceCompileOnly_43(int id0);
  public void SetForceCompileOnly(int id0)
    { SetForceCompileOnly_43(id0); }

  private native void SetScalarMode_44(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_44(id0); }

  private native int GetScalarMode_45();
  public int GetScalarMode()
    { return GetScalarMode_45(); }

  private native void SetScalarModeToDefault_46();
  public void SetScalarModeToDefault()
    { SetScalarModeToDefault_46(); }

  private native void SetScalarModeToUsePointData_47();
  public void SetScalarModeToUsePointData()
    { SetScalarModeToUsePointData_47(); }

  private native void SetScalarModeToUseCellData_48();
  public void SetScalarModeToUseCellData()
    { SetScalarModeToUseCellData_48(); }

  private native void SetScalarModeToUsePointFieldData_49();
  public void SetScalarModeToUsePointFieldData()
    { SetScalarModeToUsePointFieldData_49(); }

  private native void SetScalarModeToUseCellFieldData_50();
  public void SetScalarModeToUseCellFieldData()
    { SetScalarModeToUseCellFieldData_50(); }

  private native void SetScalarModeToUseFieldData_51();
  public void SetScalarModeToUseFieldData()
    { SetScalarModeToUseFieldData_51(); }

  private native void SelectColorArray_52(int id0);
  public void SelectColorArray(int id0)
    { SelectColorArray_52(id0); }

  private native void SelectColorArray_53(String id0);
  public void SelectColorArray(String id0)
    { SelectColorArray_53(id0); }

  private native void SetFieldDataTupleId_54(int id0);
  public void SetFieldDataTupleId(int id0)
    { SetFieldDataTupleId_54(id0); }

  private native int GetFieldDataTupleId_55();
  public int GetFieldDataTupleId()
    { return GetFieldDataTupleId_55(); }

  private native void ColorByArrayComponent_56(int id0,int id1);
  public void ColorByArrayComponent(int id0,int id1)
    { ColorByArrayComponent_56(id0,id1); }

  private native void ColorByArrayComponent_57(String id0,int id1);
  public void ColorByArrayComponent(String id0,int id1)
    { ColorByArrayComponent_57(id0,id1); }

  private native String GetArrayName_58();
  public String GetArrayName()
    { return GetArrayName_58(); }

  private native void SetArrayName_59(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_59(id0); }

  private native int GetArrayId_60();
  public int GetArrayId()
    { return GetArrayId_60(); }

  private native void SetArrayId_61(int id0);
  public void SetArrayId(int id0)
    { SetArrayId_61(id0); }

  private native int GetArrayAccessMode_62();
  public int GetArrayAccessMode()
    { return GetArrayAccessMode_62(); }

  private native void SetArrayAccessMode_63(int id0);
  public void SetArrayAccessMode(int id0)
    { SetArrayAccessMode_63(id0); }

  private native int GetArrayComponent_64();
  public int GetArrayComponent()
    { return GetArrayComponent_64(); }

  private native void SetArrayComponent_65(int id0);
  public void SetArrayComponent(int id0)
    { SetArrayComponent_65(id0); }

  private native String GetScalarModeAsString_66();
  public String GetScalarModeAsString()
    { return GetScalarModeAsString_66(); }

  private native void SetResolveCoincidentTopology_67(int id0);
  public void SetResolveCoincidentTopology(int id0)
    { SetResolveCoincidentTopology_67(id0); }

  private native int GetResolveCoincidentTopology_68();
  public int GetResolveCoincidentTopology()
    { return GetResolveCoincidentTopology_68(); }

  private native void SetResolveCoincidentTopologyToDefault_69();
  public void SetResolveCoincidentTopologyToDefault()
    { SetResolveCoincidentTopologyToDefault_69(); }

  private native void SetResolveCoincidentTopologyToOff_70();
  public void SetResolveCoincidentTopologyToOff()
    { SetResolveCoincidentTopologyToOff_70(); }

  private native void SetResolveCoincidentTopologyToPolygonOffset_71();
  public void SetResolveCoincidentTopologyToPolygonOffset()
    { SetResolveCoincidentTopologyToPolygonOffset_71(); }

  private native void SetResolveCoincidentTopologyToShiftZBuffer_72();
  public void SetResolveCoincidentTopologyToShiftZBuffer()
    { SetResolveCoincidentTopologyToShiftZBuffer_72(); }

  private native void SetResolveCoincidentTopologyPolygonOffsetParameters_73(double id0,double id1);
  public void SetResolveCoincidentTopologyPolygonOffsetParameters(double id0,double id1)
    { SetResolveCoincidentTopologyPolygonOffsetParameters_73(id0,id1); }

  private native void SetRelativeCoincidentTopologyPolygonOffsetParameters_74(double id0,double id1);
  public void SetRelativeCoincidentTopologyPolygonOffsetParameters(double id0,double id1)
    { SetRelativeCoincidentTopologyPolygonOffsetParameters_74(id0,id1); }

  private native void SetResolveCoincidentTopologyLineOffsetParameters_75(double id0,double id1);
  public void SetResolveCoincidentTopologyLineOffsetParameters(double id0,double id1)
    { SetResolveCoincidentTopologyLineOffsetParameters_75(id0,id1); }

  private native void SetRelativeCoincidentTopologyLineOffsetParameters_76(double id0,double id1);
  public void SetRelativeCoincidentTopologyLineOffsetParameters(double id0,double id1)
    { SetRelativeCoincidentTopologyLineOffsetParameters_76(id0,id1); }

  private native void SetResolveCoincidentTopologyPointOffsetParameter_77(double id0);
  public void SetResolveCoincidentTopologyPointOffsetParameter(double id0)
    { SetResolveCoincidentTopologyPointOffsetParameter_77(id0); }

  private native void SetRelativeCoincidentTopologyPointOffsetParameter_78(double id0);
  public void SetRelativeCoincidentTopologyPointOffsetParameter(double id0)
    { SetRelativeCoincidentTopologyPointOffsetParameter_78(id0); }

  private native void SetResolveCoincidentTopologyPolygonOffsetFaces_79(int id0);
  public void SetResolveCoincidentTopologyPolygonOffsetFaces(int id0)
    { SetResolveCoincidentTopologyPolygonOffsetFaces_79(id0); }

  private native int GetResolveCoincidentTopologyPolygonOffsetFaces_80();
  public int GetResolveCoincidentTopologyPolygonOffsetFaces()
    { return GetResolveCoincidentTopologyPolygonOffsetFaces_80(); }

  private native void SetResolveCoincidentTopologyZShift_81(double id0);
  public void SetResolveCoincidentTopologyZShift(double id0)
    { SetResolveCoincidentTopologyZShift_81(id0); }

  private native double GetResolveCoincidentTopologyZShift_82();
  public double GetResolveCoincidentTopologyZShift()
    { return GetResolveCoincidentTopologyZShift_82(); }

  private native double[] GetBounds_83();
  public double[] GetBounds()
    { return GetBounds_83(); }

  private native void GetBounds_84(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_84(id0); }

  private native void SetRenderTime_85(double id0);
  public void SetRenderTime(double id0)
    { SetRenderTime_85(id0); }

  private native double GetRenderTime_86();
  public double GetRenderTime()
    { return GetRenderTime_86(); }

  private native long GetInputAsDataSet_87();
  public vtkDataSet GetInputAsDataSet() {
    long temp = GetInputAsDataSet_87();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long MapScalars_88(double id0);
  public vtkUnsignedCharArray MapScalars(double id0) {
    long temp = MapScalars_88(id0);

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long MapScalars_89(vtkDataSet id0,double id1);
  public vtkUnsignedCharArray MapScalars(vtkDataSet id0,double id1) {
    long temp = MapScalars_89(id0,id1);

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarMaterialMode_90(int id0);
  public void SetScalarMaterialMode(int id0)
    { SetScalarMaterialMode_90(id0); }

  private native int GetScalarMaterialMode_91();
  public int GetScalarMaterialMode()
    { return GetScalarMaterialMode_91(); }

  private native void SetScalarMaterialModeToDefault_92();
  public void SetScalarMaterialModeToDefault()
    { SetScalarMaterialModeToDefault_92(); }

  private native void SetScalarMaterialModeToAmbient_93();
  public void SetScalarMaterialModeToAmbient()
    { SetScalarMaterialModeToAmbient_93(); }

  private native void SetScalarMaterialModeToDiffuse_94();
  public void SetScalarMaterialModeToDiffuse()
    { SetScalarMaterialModeToDiffuse_94(); }

  private native void SetScalarMaterialModeToAmbientAndDiffuse_95();
  public void SetScalarMaterialModeToAmbientAndDiffuse()
    { SetScalarMaterialModeToAmbientAndDiffuse_95(); }

  private native String GetScalarMaterialModeAsString_96();
  public String GetScalarMaterialModeAsString()
    { return GetScalarMaterialModeAsString_96(); }

  private native boolean GetIsOpaque_97();
  public boolean GetIsOpaque()
    { return GetIsOpaque_97(); }

  private native boolean GetSupportsSelection_98();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_98(); }

  private native int CanUseTextureMapForColoring_99(vtkDataObject id0);
  public int CanUseTextureMapForColoring(vtkDataObject id0)
    { return CanUseTextureMapForColoring_99(id0); }

  private native void ClearColorArrays_100();
  public void ClearColorArrays()
    { ClearColorArrays_100(); }

  private native long GetColorMapColors_101();
  public vtkUnsignedCharArray GetColorMapColors() {
    long temp = GetColorMapColors_101();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetColorCoordinates_102();
  public vtkFloatArray GetColorCoordinates() {
    long temp = GetColorCoordinates_102();

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetColorTextureMap_103();
  public vtkImageData GetColorTextureMap() {
    long temp = GetColorTextureMap_103();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkMapper() { super(); }

  public vtkMapper(long id) { super(id); }

}
